summaryrefslogtreecommitdiff
path: root/ir.h
diff options
context:
space:
mode:
Diffstat (limited to 'ir.h')
-rw-r--r--ir.h6
1 files changed, 5 insertions, 1 deletions
diff --git a/ir.h b/ir.h
index 559f984478..381af357b8 100644
--- a/ir.h
+++ b/ir.h
@@ -299,7 +299,9 @@ public:
ir_rvalue *condition;
};
/* Update ir_print_visitor.cpp when updating this list. */
enum ir_expression_operation {
ir_unop_bit_not,
ir_unop_logic_not,
@@ -370,6 +372,8 @@ public:
ir_expression(int op, const struct glsl_type *type,
ir_rvalue *, ir_rvalue *);
+ unsigned int get_num_operands(void);
+
virtual void accept(ir_visitor *v)
{
v->visit(this);
@@ -299,7 +299,9 @@ public:
ir_rvalue *condition;
};
-/* Update ir_print_visitor.cpp when updating this list. */
+/* Update ir_expression::num_operands() and ir_print_visitor.cpp when
+ * updating this list.
+*/
enum ir_expression_operation {
ir_unop_bit_not,